==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/bean/RevolvingleaseEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.RevolvingleasedetailEntity;
/**
 * 月度周转工具租赁费结算单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_revolvinglease")
public class RevolvingleaseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="lessee_id")
    private java.lang.Long lesseeId; // 租赁商id
    @TableField(value="lessee_name")
    private java.lang.String lesseeName; // 租赁商名称
    @TableField(value="settle_account")
    private java.math.BigDecimal settleAccount; // 结算金额(除税)
    @TableField(value="tax_settle_account")
    private java.math.BigDecimal taxSettleAccount; // 结算金额(含税)
    @TableField(value="settle_time")
    private java.util.Date settleTime; // 结算时间
    @TableField(value="start_time")
    private java.util.Date startTime; // 计费起始时间
    @TableField(value="deadline")
    private java.util.Date deadline; // 计费截至时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编号
    @TableField(value="total")
    private java.math.BigDecimal total; // 本月合计(除税)
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 本月合计(含税)
    @TableField(value="occurrence_total")
    private java.math.BigDecimal occurrenceTotal; // 累计发生(除税)
    @TableField(value="tax_occurrence_total")
    private java.math.BigDecimal taxOccurrenceTotal; // 累计结算金额汇总(含税)
    @TableField(value="is_reference")
    private java.lang.Integer isReference; // 是否被汇总表引用(0:否，1:是)
    @TableField(value="reference_id")
    private java.lang.Long referenceId; // 引用租赁单的汇总单id
    @TableField(value="reference_code")
    private java.lang.String referenceCode; // 引用租赁单的汇总单code
    @TableField(value="save_time")
    private java.util.Date saveTime; // 保存时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="revolvingleasedetailService", pidName = "mid")
    private List<RevolvingleasedetailEntity> revolvingleasedetailEntities = new ArrayList<>(); // 月度周转工具租赁费结算单子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 租赁商id
     */
    public java.lang.Long getLesseeId() {
        return lesseeId;
    }

    /**
     * 租赁商id
     */
    public void setLesseeId(java.lang.Long lesseeId) {
        this.lesseeId = lesseeId;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getLesseeName() {
        return lesseeName;
    }

    /**
     * 租赁商名称
     */
    public void setLesseeName(java.lang.String lesseeName) {
        this.lesseeName = lesseeName;
    }
    /**
     * 结算金额(除税)
     */
    public java.math.BigDecimal getSettleAccount() {
        return settleAccount;
    }

    /**
     * 结算金额(除税)
     */
    public void setSettleAccount(java.math.BigDecimal settleAccount) {
        this.settleAccount = settleAccount;
    }
    /**
     * 结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettleAccount() {
        return taxSettleAccount;
    }

    /**
     * 结算金额(含税)
     */
    public void setTaxSettleAccount(java.math.BigDecimal taxSettleAccount) {
        this.taxSettleAccount = taxSettleAccount;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettleTime() {
        return settleTime;
    }

    /**
     * 结算时间
     */
    public void setSettleTime(java.util.Date settleTime) {
        this.settleTime = settleTime;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getStartTime() {
        return startTime;
    }

    /**
     * 计费起始时间
     */
    public void setStartTime(java.util.Date startTime) {
        this.startTime = startTime;
    }
    /**
     * 计费截至时间
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 计费截至时间
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 本月合计(除税)
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 本月合计(除税)
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 本月合计(含税)
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 本月合计(含税)
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 累计发生(除税)
     */
    public java.math.BigDecimal getOccurrenceTotal() {
        return occurrenceTotal;
    }

    /**
     * 累计发生(除税)
     */
    public void setOccurrenceTotal(java.math.BigDecimal occurrenceTotal) {
        this.occurrenceTotal = occurrenceTotal;
    }
    /**
     * 累计结算金额汇总(含税)
     */
    public java.math.BigDecimal getTaxOccurrenceTotal() {
        return taxOccurrenceTotal;
    }

    /**
     * 累计结算金额汇总(含税)
     */
    public void setTaxOccurrenceTotal(java.math.BigDecimal taxOccurrenceTotal) {
        this.taxOccurrenceTotal = taxOccurrenceTotal;
    }
    
    /**
     * 月度周转工具租赁费结算单子表
     */
    public List<RevolvingleasedetailEntity> getRevolvingleasedetailEntities() {
        return revolvingleasedetailEntities;
    }

    /**
     * 月度周转工具租赁费结算单子表
     */
    public void setRevolvingleasedetailEntities(List<RevolvingleasedetailEntity> revolvingleasedetailEntities) {
        this.revolvingleasedetailEntities = revolvingleasedetailEntities;
    }

    public Integer getIsReference() {
        return isReference;
    }

    public void setIsReference(Integer isReference) {
        this.isReference = isReference;
    }

    public Long getReferenceId() {
        return referenceId;
    }

    public void setReferenceId(Long referenceId) {
        this.referenceId = referenceId;
    }

    public String getReferenceCode() {
        return referenceCode;
    }

    public void setReferenceCode(String referenceCode) {
        this.referenceCode = referenceCode;
    }

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20220621.090612-110-sources.jar: com/ejianc/business/middlemeasurement/bean/RevolvingleaseEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.RevolvingleasedetailEntity;
/**
 * 月度周转工具租赁费结算单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_revolvinglease")
public class RevolvingleaseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="lessee_id")
    private java.lang.Long lesseeId; // 租赁商id
    @TableField(value="lessee_name")
    private java.lang.String lesseeName; // 租赁商名称
    @TableField(value="settle_account")
    private java.math.BigDecimal settleAccount; // 结算金额(除税)
    @TableField(value="tax_settle_account")
    private java.math.BigDecimal taxSettleAccount; // 结算金额(含税)
    @TableField(value="settle_time")
    private java.util.Date settleTime; // 结算时间
    @TableField(value="start_time")
    private java.util.Date startTime; // 计费起始时间
    @TableField(value="deadline")
    private java.util.Date deadline; // 计费截至时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编号
    @TableField(value="total")
    private java.math.BigDecimal total; // 本月合计(除税)
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 本月合计(含税)
    @TableField(value="occurrence_total")
    private java.math.BigDecimal occurrenceTotal; // 累计发生(除税)
    @TableField(value="tax_occurrence_total")
    private java.math.BigDecimal taxOccurrenceTotal; // 累计结算金额汇总(含税)
    @TableField(value="is_reference")
    private java.lang.Integer isReference; // 是否被汇总表引用(0:否，1:是)
    @TableField(value="reference_id")
    private java.lang.Long referenceId; // 引用租赁单的汇总单id
    @TableField(value="reference_code")
    private java.lang.String referenceCode; // 引用租赁单的汇总单code
    @TableField(value="save_time")
    private java.util.Date saveTime; // 保存时间

    @TableField(value = "org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value = "org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value = "project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="revolvingleasedetailService", pidName = "mid")
    private List<RevolvingleasedetailEntity> revolvingleasedetailEntities = new ArrayList<>(); // 月度周转工具租赁费结算单子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 租赁商id
     */
    public java.lang.Long getLesseeId() {
        return lesseeId;
    }

    /**
     * 租赁商id
     */
    public void setLesseeId(java.lang.Long lesseeId) {
        this.lesseeId = lesseeId;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getLesseeName() {
        return lesseeName;
    }

    /**
     * 租赁商名称
     */
    public void setLesseeName(java.lang.String lesseeName) {
        this.lesseeName = lesseeName;
    }
    /**
     * 结算金额(除税)
     */
    public java.math.BigDecimal getSettleAccount() {
        return settleAccount;
    }

    /**
     * 结算金额(除税)
     */
    public void setSettleAccount(java.math.BigDecimal settleAccount) {
        this.settleAccount = settleAccount;
    }
    /**
     * 结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettleAccount() {
        return taxSettleAccount;
    }

    /**
     * 结算金额(含税)
     */
    public void setTaxSettleAccount(java.math.BigDecimal taxSettleAccount) {
        this.taxSettleAccount = taxSettleAccount;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettleTime() {
        return settleTime;
    }

    /**
     * 结算时间
     */
    public void setSettleTime(java.util.Date settleTime) {
        this.settleTime = settleTime;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getStartTime() {
        return startTime;
    }

    /**
     * 计费起始时间
     */
    public void setStartTime(java.util.Date startTime) {
        this.startTime = startTime;
    }
    /**
     * 计费截至时间
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 计费截至时间
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 本月合计(除税)
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 本月合计(除税)
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 本月合计(含税)
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 本月合计(含税)
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 累计发生(除税)
     */
    public java.math.BigDecimal getOccurrenceTotal() {
        return occurrenceTotal;
    }

    /**
     * 累计发生(除税)
     */
    public void setOccurrenceTotal(java.math.BigDecimal occurrenceTotal) {
        this.occurrenceTotal = occurrenceTotal;
    }
    /**
     * 累计结算金额汇总(含税)
     */
    public java.math.BigDecimal getTaxOccurrenceTotal() {
        return taxOccurrenceTotal;
    }

    /**
     * 累计结算金额汇总(含税)
     */
    public void setTaxOccurrenceTotal(java.math.BigDecimal taxOccurrenceTotal) {
        this.taxOccurrenceTotal = taxOccurrenceTotal;
    }
    
    /**
     * 月度周转工具租赁费结算单子表
     */
    public List<RevolvingleasedetailEntity> getRevolvingleasedetailEntities() {
        return revolvingleasedetailEntities;
    }

    /**
     * 月度周转工具租赁费结算单子表
     */
    public void setRevolvingleasedetailEntities(List<RevolvingleasedetailEntity> revolvingleasedetailEntities) {
        this.revolvingleasedetailEntities = revolvingleasedetailEntities;
    }

    public Integer getIsReference() {
        return isReference;
    }

    public void setIsReference(Integer isReference) {
        this.isReference = isReference;
    }

    public Long getReferenceId() {
        return referenceId;
    }

    public void setReferenceId(Long referenceId) {
        this.referenceId = referenceId;
    }

    public String getReferenceCode() {
        return referenceCode;
    }

    public void setReferenceCode(String referenceCode) {
        this.referenceCode = referenceCode;
    }

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
}
